def badword(bw,f):
	user_input=bw
	for filter_word in open(f,encoding='utf-8'):
	    fw=filter_word.rstrip()
	    if fw in user_input:
	        fw_len=len(fw)
	        user_input=user_input.replace(fw,'不'+fw)
	else:
	           user_input=user_input.replace("是不","不是").replace('不不','不').replace('想不','不想')

	return user_input


from setuptools import setup
 
NAME = 'badwords'
VERSION = '1.2.4.0'
PY_MODULES = ['badwords']
setup(name = NAME
        , version = VERSION
        , py_modules = PY_MODULES,
      description='a small pkg demos for you and everyone',
      long_description='''
```shell
pip install badwords
```
_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-

'''
      ,long_description_content_type='text/markdown'
) 
